package demo;

import com.microsoft.signalr.HubConnection;
import com.microsoft.signalr.HubConnectionBuilder;

import io.reactivex.Single;

import java.util.Scanner;

public class App {

    public static void main(String[] args) {

        if (args.length < 2) {
            System.out.println("usage: java -jar app.jar URL_TO_SERVICE APIKEY\nWhere URL_TO_SERVICE is 'http://host:port' (without / at the end)\n");
            System.exit(2);
            return;
        }

        String url = args[0].trim();
        url += (url.endsWith("/") ? "" : "/") + "rt-api/orderstate";

        String api_key = args[1].trim();
        

        HubConnection hubConnection = HubConnectionBuilder.create(url)
            .withAccessTokenProvider(Single.defer(() -> {
                    return Single.just("apikey-" + api_key);
                    })).build();

        hubConnection.onClosed((exception -> {
            String exStr = (exception ==null) ? "no error" : exception.toString();
            System.out.print("connection closed: " + exStr);            
        }));

        hubConnection.on("OrderStateChanged", (orderNumber, pickupCode, newState, changedDate, extraInfo) -> {
                    System.out.println("order with order number: " + orderNumber + " and pickup code: " + orderNumber + " changed to: " + newState + " at: " + changedDate);
                    if (extraInfo != null) System.out.println("extrainfo: " + extraInfo);
            }, String.class, String.class, String.class, String.class, String.class);

        System.out.print("connecting to " + url + " ...");

        try {
          //This is a blocking call
           hubConnection.start().blockingAwait();
        } catch (Exception e) {
           System.out.println("failed: " + e.getMessage());
           System.exit(1);
           return;
        }

        Scanner reader = new Scanner(System.in);
        System.out.println("connected. press enter to disconnect");  
        reader.nextLine();    
        hubConnection.stop().blockingAwait();

        System.out.println("disconnected.");
        reader.close();

	System.exit(0);

    }
}
